summaryrefslogtreecommitdiff
path: root/include/vcl/toolbox.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'include/vcl/toolbox.hxx')
-rw-r--r--include/vcl/toolbox.hxx10
1 files changed, 8 insertions, 2 deletions
diff --git a/include/vcl/toolbox.hxx b/include/vcl/toolbox.hxx
index ab1dfaf3a1a1..d7b6af8e92b9 100644
--- a/include/vcl/toolbox.hxx
+++ b/include/vcl/toolbox.hxx
@@ -58,9 +58,15 @@ namespace o3tl
template<> struct typed_flags<ToolBoxMenuType> : is_typed_flags<ToolBoxMenuType, 0x0003> {};
}
// small or large force an exact toolbox size for proper alignemnt
// dontcare will let the toolbox decide about its size
-enum class ToolBoxButtonSize { DontCare, Small, Large };
+enum class ToolBoxButtonSize
+{
+ DontCare,
+ Small,
+ Large,
+ Size32,
+};
// ToolBoxLayoutMode::Normal - traditional layout, items are centered in the toolbar
// ToolBoxLayoutMode::LockVert - special mode (currently used for calc input/formula
@@ -58,9 +58,15 @@ namespace o3tl
template<> struct typed_flags<ToolBoxMenuType> : is_typed_flags<ToolBoxMenuType, 0x0003> {};
}
-// small or large force an exact toolbox size for proper alignemnt
+// small, large, size32 force an exact toolbox size for proper alignemnt
// dontcare will let the toolbox decide about its size